# sudapy.core.errors

Custom exceptions with user-friendly hints.

::: sudapy.core.errors
    options:
      show_root_heading: true
      heading_level: 2
      members_order: source
      show_source: true
      docstring_style: google
      show_signature_annotations: true
      separate_signature: true
